==> pyskool-0.2.1.zip: pyskool-0.2.1/pyskool/keys.py <==
# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

import pygame

# Cheat keys
SLOW = pygame.K_9
FAST = pygame.K_0
NEXT_LESSON = pygame.K_TAB
FLASH_MOST = pygame.K_1
UNFLASH_MOST = pygame.K_2
NO_LINES = pygame.K_3
ADD_LINES = pygame.K_4
ZERO_LINES = pygame.K_5
REVEAL = pygame.K_6
GIVE_ALL = pygame.K_7
SWITCH_PISTOL = pygame.K_8
OPEN_DOORS = pygame.K_PAGEUP
CLOSE_DOORS = pygame.K_PAGEDOWN

# Special keys
QUIT = pygame.K_ESCAPE
PAUSE = pygame.K_END
SCREENSHOT = pygame.K_INSERT

# Movement keys
SIT_STAND = pygame.K_s
OPEN_DESK = pygame.K_o
FIRE_CATAPULT = pygame.K_f
FIRE_WATER_PISTOL = pygame.K_g
DROP_STINKBOMB = pygame.K_d
HIT = pygame.K_h
JUMP = pygame.K_j
WRITE = pygame.K_w
ENTER = pygame.K_RETURN
CATCH = pygame.K_c
LEFT = pygame.K_LEFT
RIGHT = pygame.K_RIGHT
UP = pygame.K_UP
DOWN = pygame.K_DOWN
UNDERSTOOD = pygame.K_u
MOUNT_BIKE = pygame.K_m
DUMP_WATER_PISTOL = pygame.K_t
RELEASE_MICE = pygame.K_r
KISS = pygame.K_k

==> pyskool-0.2.2.zip: pyskool-0.2.2/pyskool/keys.py <==
# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

import pygame

# Cheat keys
SLOW = pygame.K_9
FAST = pygame.K_0
NEXT_LESSON = pygame.K_TAB
FLASH_MOST = pygame.K_1
UNFLASH_MOST = pygame.K_2
NO_LINES = pygame.K_3
ADD_LINES = pygame.K_4
ZERO_LINES = pygame.K_5
REVEAL = pygame.K_6
GIVE_ALL = pygame.K_7
SWITCH_PISTOL = pygame.K_8
OPEN_DOORS = pygame.K_PAGEUP
CLOSE_DOORS = pygame.K_PAGEDOWN

# Special keys
QUIT = pygame.K_ESCAPE
PAUSE = pygame.K_END
SCREENSHOT = pygame.K_INSERT

# Movement keys
LEFT = [pygame.K_LEFT, pygame.K_o]
RIGHT = [pygame.K_RIGHT, pygame.K_p]
UP = [pygame.K_UP, pygame.K_q]
DOWN = [pygame.K_DOWN, pygame.K_a]
SIT_STAND = [pygame.K_s]
OPEN_DESK = [pygame.K_o]
FIRE_CATAPULT = [pygame.K_f]
FIRE_WATER_PISTOL = [pygame.K_g]
DROP_STINKBOMB = [pygame.K_d]
HIT = [pygame.K_h]
JUMP = [pygame.K_j]
WRITE = [pygame.K_w]
ENTER = [pygame.K_RETURN]
CATCH = [pygame.K_c]
UNDERSTOOD = [pygame.K_u]
MOUNT_BIKE = [pygame.K_m]
DUMP_WATER_PISTOL = [pygame.K_t]
RELEASE_MICE = [pygame.K_r]
KISS = [pygame.K_k]
